@@ -77,41 +77,41 @@ public:
 
     Private()
     {
-        fileBox            = 0;
-        titleEdit          = 0;
-        descEdit           = 0;
-        dateEdit           = 0;
-        longitudeEdit      = 0;
-        latitudeEdit       = 0;
-        categoryEdit       = 0;
-        loginHeaderLbl     = 0;
-        nameEdit           = 0;
-        passwdEdit         = 0;
-        newWikiSv          = 0;
-        newWikiNameEdit    = 0;
-        newWikiUrlEdit     = 0;
-        wikiSelect         = 0;
-        authorEdit         = 0;
-        sourceEdit         = 0;
-        genCatEdit         = 0;
-        genTxtEdit         = 0;
-        genComEdit         = 0;
-        headerLbl          = 0;
-        wikiNameDisplayLbl = 0;
-        userNameDisplayLbl = 0;
-        changeUserBtn      = 0;
-        resizeChB          = 0;
-        dimensionSpB       = 0;
-        imageQualitySpB    = 0;
-        removeMetaChB      = 0;
-        removeGeoChB       = 0;
-        licenseComboBox    = 0;
-        progressBar        = 0;
-        imgList            = 0;
-        uploadWidget       = 0;
+        fileBox            = nullptr;
+        titleEdit          = nullptr;
+        descEdit           = nullptr;
+        dateEdit           = nullptr;
+        longitudeEdit      = nullptr;
+        latitudeEdit       = nullptr;
+        categoryEdit       = nullptr;
+        loginHeaderLbl     = nullptr;
+        nameEdit           = nullptr;
+        passwdEdit         = nullptr;
+        newWikiSv          = nullptr;
+        newWikiNameEdit    = nullptr;
+        newWikiUrlEdit     = nullptr;
+        wikiSelect         = nullptr;
+        authorEdit         = nullptr;
+        sourceEdit         = nullptr;
+        genCatEdit         = nullptr;
+        genTxtEdit         = nullptr;
+        genComEdit         = nullptr;
+        headerLbl          = nullptr;
+        wikiNameDisplayLbl = nullptr;
+        userNameDisplayLbl = nullptr;
+        changeUserBtn      = nullptr;
+        resizeChB          = nullptr;
+        dimensionSpB       = nullptr;
+        imageQualitySpB    = nullptr;
+        removeMetaChB      = nullptr;
+        removeGeoChB       = nullptr;
+        licenseComboBox    = nullptr;
+        progressBar        = nullptr;
+        imgList            = nullptr;
+        uploadWidget       = nullptr;
         defaultMessage     = i18n("Select an image");
-        loginGBox          = 0;
-        userGBox           = 0;
+        loginGBox          = nullptr;
+        userGBox           = nullptr;
     }
 
     QWidget*                                 fileBox;
